@@ -6,7 +6,7 @@ Renamed from all_of_merger to all_of_parser for consistency.
 from __future__ import annotations
 
 import os
-from typing import TYPE_CHECKING, Any, Callable, Dict, List, Mapping, Optional, Set, Tuple
+from typing import TYPE_CHECKING, Any, Callable, List, Mapping, Set, Tuple
 
 from pyopenapi_gen import IRSchema
 
@@ -20,11 +20,11 @@ if TYPE_CHECKING:
 
 def _process_all_of(
     node: Mapping[str, Any],
-    current_schema_name: Optional[str],
+    current_schema_name: str | None,
     context: ParsingContext,
-    _parse_schema_func: Callable[[Optional[str], Optional[Mapping[str, Any]], ParsingContext, Optional[int]], IRSchema],
+    _parse_schema_func: Callable[[str | None, Mapping[str, Any] | None, ParsingContext, int | None], IRSchema],
     max_depth: int = ENV_MAX_DEPTH,
-) -> Tuple[Dict[str, IRSchema], Set[str], List[IRSchema]]:
+) -> Tuple[dict[str, IRSchema], Set[str], List[IRSchema]]:
     """Processes the 'allOf' keyword in a schema node.
 
     Merges properties and required fields from all sub-schemas listed in 'allOf'
@@ -54,7 +54,7 @@ def _process_all_of(
 
     parsed_all_of_components: List[IRSchema] = []
     merged_required: Set[str] = set(node.get("required", []))
-    merged_properties: Dict[str, IRSchema] = {}
+    merged_properties: dict[str, IRSchema] = {}
 
     if "allOf" not in node:
         current_node_direct_properties = node.get("properties", {})
