@@ -328,10 +328,13 @@ class DataclassSerializer:
             The serialized object with dataclasses converted to dictionaries.
 
         Handles:
-        - Dataclass instances: Converted to dictionaries
+        - Dataclass instances with Meta.key_transform_with_dump: Applies field name mapping (snake_case → camelCase)
+        - Legacy BaseSchema instances: Falls back to to_dict() if present (backward compatibility)
+        - Regular dataclass instances: Converted to dictionaries using field names
         - Lists: Recursively serialize each item
         - Dictionaries: Recursively serialize values
         - datetime: Convert to ISO format string
+        - Enums: Convert to their value
         - Primitives: Return unchanged
         - None values: Excluded from output
         """
@@ -341,6 +344,7 @@ class DataclassSerializer:
     @staticmethod
     def _serialize_with_tracking(obj: Any, visited: Set[int]) -> Any:
         """Internal serialization method with circular reference tracking."""
+        from enum import Enum
 
         # Handle None values by excluding them
         if obj is None:
@@ -358,18 +362,50 @@ class DataclassSerializer:
         if isinstance(obj, datetime):
             return obj.isoformat()
 
-        # Handle dataclass instances
+        # Handle enum instances
+        if isinstance(obj, Enum) and not isinstance(obj, type):
+            return obj.value
+
+        # Handle legacy BaseSchema instances (backward compatibility)
+        # Check for BaseSchema by looking for both to_dict and _get_field_mappings methods
+        if hasattr(obj, "to_dict") and hasattr(obj, "_get_field_mappings") and callable(obj.to_dict):
+            visited.add(obj_id)
+            try:
+                # Use legacy BaseSchema's to_dict() which handles field name mapping
+                result_dict = obj.to_dict(exclude_none=True)
+                # Recursively serialize nested objects in the result
+                serialized_result = {}
+                for key, value in result_dict.items():
+                    serialized_value = DataclassSerializer._serialize_with_tracking(value, visited)
+                    if serialized_value is not None:
+                        serialized_result[key] = serialized_value
+                return serialized_result
+            finally:
+                visited.discard(obj_id)
+
+        # Handle regular dataclass instances (with cattrs field mapping support)
         if dataclasses.is_dataclass(obj) and not isinstance(obj, type):
             visited.add(obj_id)
             try:
-                result = {}
+                # Build dict from dataclass fields without recursive unstructuring
+                data: dict[str, Any] = {}
                 for field in dataclasses.fields(obj):
                     value = getattr(obj, field.name)
-                    # Skip None values to keep JSON clean
+                    data[field.name] = value
+
+                # Apply field name mapping if Meta class exists
+                if hasattr(obj, "Meta") and hasattr(obj.Meta, "key_transform_with_dump"):
+                    mappings = obj.Meta.key_transform_with_dump
+                    # Transform keys according to mapping
+                    data = {mappings.get(k, k): v for k, v in data.items()}
+
+                # Recursively serialize nested objects and skip None values
+                result = {}
+                for key, value in data.items():
                     if value is not None:
                         serialized_value = DataclassSerializer._serialize_with_tracking(value, visited)
                         if serialized_value is not None:
-                            result[field.name] = serialized_value
+                            result[key] = serialized_value
                 return result
             finally:
                 visited.discard(obj_id)
