@@ -10,7 +10,7 @@ RUNTIME_FILES = [
     ("pyopenapi_gen.core", "exceptions.py", "core/exceptions.py"),
     ("pyopenapi_gen.core", "streaming_helpers.py", "core/streaming_helpers.py"),
     ("pyopenapi_gen.core", "pagination.py", "core/pagination.py"),
-    ("pyopenapi_gen.core", "schemas.py", "core/schemas.py"),
+    ("pyopenapi_gen.core", "cattrs_converter.py", "core/cattrs_converter.py"),
     ("pyopenapi_gen.core", "utils.py", "core/utils.py"),
     ("pyopenapi_gen.core.auth", "base.py", "core/auth/base.py"),
     ("pyopenapi_gen.core.auth", "plugins.py", "core/auth/plugins.py"),
@@ -87,7 +87,7 @@ class CoreEmitter:
             "# Re-export other commonly used core components",
             "from .http_transport import HttpTransport, HttpxTransport",
             "from .config import ClientConfig",
-            "from .schemas import BaseSchema",
+            "from .cattrs_converter import structure_from_dict, unstructure_to_dict, converter",
             "from .utils import DataclassSerializer",
             "from .auth.base import BaseAuth",
             "from .auth.plugins import ApiKeyAuth, BearerAuth, OAuth2Auth",
@@ -106,8 +106,10 @@ class CoreEmitter:
             "    # Configuration",
             '    "ClientConfig",',
             "",
-            "    # Schemas",
-            '    "BaseSchema",',
+            "    # Serialization (cattrs)",
+            '    "structure_from_dict",',
+            '    "unstructure_to_dict",',
+            '    "converter",',
             "",
             "    # Utilities",
             '    "DataclassSerializer",',
