@@ -19,6 +19,7 @@ from pyopenapi_gen.emitters.client_emitter import ClientEmitter
 from pyopenapi_gen.emitters.core_emitter import CoreEmitter
 from pyopenapi_gen.emitters.endpoints_emitter import EndpointsEmitter
 from pyopenapi_gen.emitters.exceptions_emitter import ExceptionsEmitter
+from pyopenapi_gen.emitters.mocks_emitter import MocksEmitter
 from pyopenapi_gen.emitters.models_emitter import ModelsEmitter
 
 logger = logging.getLogger(__name__)
@@ -277,6 +278,13 @@ class ClientGenerator:
                 temp_generated_files += client_files
                 self._log_progress(f"Generated {len(client_files)} client files (temp)", "EMIT_CLIENT_TEMP")
 
+                # 7. MocksEmitter (emits mock files to tmp_out_dir_for_diff)
+                self._log_progress("Generating mock helper classes (temp)", "EMIT_MOCKS_TEMP")
+                mocks_emitter = MocksEmitter(context=tmp_render_context_for_diff)
+                mock_files = [Path(p) for p in mocks_emitter.emit(ir, str(tmp_out_dir_for_diff))]
+                temp_generated_files += mock_files
+                self._log_progress(f"Generated {len(mock_files)} mock files (temp)", "EMIT_MOCKS_TEMP")
+
                 # Post-processing should run on the temporary files if enabled
                 if not no_postprocess:
                     self._log_progress("Running post-processing on temporary files", "POSTPROCESS_TEMP")
@@ -431,6 +439,13 @@ class ClientGenerator:
             generated_files += client_files
             self._log_progress(f"Generated {len(client_files)} client files", "EMIT_CLIENT")
 
+            # 7. MocksEmitter
+            self._log_progress("Generating mock helper classes", "EMIT_MOCKS")
+            mocks_emitter = MocksEmitter(context=main_render_context)
+            mock_files = [Path(p) for p in mocks_emitter.emit(ir, str(out_dir))]
+            generated_files += mock_files
+            self._log_progress(f"Generated {len(mock_files)} mock files", "EMIT_MOCKS")
+
             # After all emitters, if core_package is specified (external core),
             # create a rich __init__.py in the client's output_package (out_dir).
             if core_package:  # core_package is the user-provided original arg
@@ -447,7 +462,7 @@ class ClientGenerator:
                     f"from {resolved_core_package_fqn}.exceptions import HTTPError, ClientError, ServerError",
                     f"from {resolved_core_package_fqn}.exception_aliases import *  # noqa: F401, F403",
                     f"from {resolved_core_package_fqn}.http_transport import HttpTransport, HttpxTransport",
-                    f"from {resolved_core_package_fqn}.schemas import BaseSchema",
+                    f"from {resolved_core_package_fqn}.cattrs_converter import structure_from_dict, unstructure_to_dict, converter",
                 ]
 
                 client_imports = [
@@ -461,7 +476,7 @@ class ClientGenerator:
                     '"HTTPError", "ClientError", "ServerError",',
                     # Names from exception_aliases are available via star import
                     '"HttpTransport", "HttpxTransport",',
-                    '"BaseSchema",',
+                    '"structure_from_dict", "unstructure_to_dict", "converter",',
                 ]
 
                 init_content_lines = [
