@@ -44,6 +44,21 @@ class OpenAPISchemaResolver(SchemaTypeResolver):
         if hasattr(schema, "ref") and schema.ref:
             return self._resolve_reference(schema.ref, context, required, resolve_underlying)
 
+        # Handle null schemas (schemas with no type and no generation_name) - resolve to Any inline
+        # These are schemas from null schema nodes in the OpenAPI spec
+        # IMPORTANT: Don't treat schemas with names that exist in the registry as null schemas
+        schema_type = getattr(schema, "type", None)
+        if (
+            schema_type is None
+            and not (hasattr(schema, "generation_name") and schema.generation_name)
+            and not (hasattr(schema, "any_of") and schema.any_of)
+            and not (hasattr(schema, "one_of") and schema.one_of)
+            and not (hasattr(schema, "all_of") and schema.all_of)
+            and not (schema.name and schema.name in getattr(self.ref_resolver, "schemas", {}))
+        ):
+            # This is a null schema - respect the required parameter for optionality
+            return self._resolve_null(context, required)
+
         # Handle named schemas with generation_name (fully processed schemas)
         if schema.name and hasattr(schema, "generation_name") and schema.generation_name:
             # If resolve_underlying is True, skip named schema resolution for type aliases
@@ -132,7 +147,7 @@ class OpenAPISchemaResolver(SchemaTypeResolver):
                 )
             elif schema_type == "None" or schema_type is None:
                 logger.info(
-                    "Schema type 'None' detected - likely an optional field or null type. This will be mapped to Optional[Any]."
+                    "Schema type 'None' detected - likely an optional field or null type. This will be mapped to Any | None."
                 )
                 return self._resolve_null(context, required)
             elif schema_type and isinstance(schema_type, str):
@@ -143,7 +158,7 @@ class OpenAPISchemaResolver(SchemaTypeResolver):
                 logger.info("  3. Custom type not supported by OpenAPI (consider using allOf/oneOf/anyOf)")
                 logger.info(f"  Location: Check your OpenAPI spec for schemas with type='{schema_type}'")
 
-            return self._resolve_any(context)
+            return self._resolve_any(context, required)
 
     def _resolve_reference(
         self, ref: str, context: TypeContext, required: bool, resolve_underlying: bool = False
@@ -186,10 +201,24 @@ class OpenAPISchemaResolver(SchemaTypeResolver):
             # If anything goes wrong with attribute access, assume not a self-reference
             current_file = None
 
-        # Only treat as self-reference if we have a real file path that matches
-        if current_file and isinstance(current_file, str) and current_file.endswith(f"{module_stem}.py"):
+        # Only treat as self-reference if the EXACT filename matches (not just a suffix)
+        # Bug fix: Use basename comparison to avoid false positives with similar names
+        # e.g., "vector_index_with_embedding_response_data.py" should NOT match "embedding_response_data.py"
+        is_self_import = False
+        if current_file and isinstance(current_file, str):
+            import os
+
+            current_filename = os.path.basename(current_file)
+            expected_filename = f"{module_stem}.py"
+            is_self_import = current_filename == expected_filename
+
+        if is_self_import:
             # This is a self-import (importing from the same file), so skip the import
             # and mark as forward reference to require quoting
+            logger.debug(
+                f"Self-import detected: current_file={current_file}, module_stem={module_stem}, "
+                f"class_name={class_name}, returning forward ref WITHOUT import"
+            )
             return ResolvedType(python_type=class_name or "Any", is_optional=not required, is_forward_ref=True)
 
         # Use the render context's relative path calculation to determine proper import path
@@ -211,6 +240,10 @@ class OpenAPISchemaResolver(SchemaTypeResolver):
                 # If relative path calculation fails, fall back to the default
                 logger.debug(f"Failed to calculate relative path for {module_stem}, using default: {e}")
 
+        logger.debug(
+            f"Adding import for named schema: module={import_module}, name={class_name}, "
+            f"current_file={current_file}, module_stem={module_stem}"
+        )
         context.add_import(import_module, class_name or "Any")
 
         return ResolvedType(
@@ -256,6 +289,7 @@ class OpenAPISchemaResolver(SchemaTypeResolver):
                 "hostname": "str",
                 "ipv4": "str",
                 "ipv6": "str",
+                "binary": "bytes",
             }
 
             python_type = format_mapping.get(format_type, "str")
@@ -287,12 +321,13 @@ class OpenAPISchemaResolver(SchemaTypeResolver):
         return ResolvedType(python_type="bool", is_optional=not required)
 
     def _resolve_null(self, context: TypeContext, required: bool) -> ResolvedType:
-        """Resolve null type."""
-        # For null types in schemas, we need to import Any for the Optional[Any] pattern
-        # But the type itself is None for union composition
-        if not required:
-            context.add_import("typing", "Any")
-        return ResolvedType(python_type="None", is_optional=not required)
+        """Resolve null type.
+
+        When a schema has type=null or no type defined (None), we map it to Python's Any type
+        because null schemas represent unknown/arbitrary data rather than the None value.
+        """
+        context.add_import("typing", "Any")
+        return ResolvedType(python_type="Any", is_optional=not required)
 
     def _resolve_array(
         self, schema: IRSchema, context: TypeContext, required: bool, resolve_underlying: bool = False
@@ -337,25 +372,25 @@ class OpenAPISchemaResolver(SchemaTypeResolver):
             # Generic object
             context.add_import("typing", "Dict")
             context.add_import("typing", "Any")
-            return ResolvedType(python_type="Dict[str, Any]", is_optional=not required)
+            return ResolvedType(python_type="dict[str, Any]", is_optional=not required)
 
         # Object with properties - should be promoted to named type
         logger.warning("Found object with properties - should be promoted to named type")
         context.add_import("typing", "Dict")
         context.add_import("typing", "Any")
-        return ResolvedType(python_type="Dict[str, Any]", is_optional=not required)
+        return ResolvedType(python_type="dict[str, Any]", is_optional=not required)
 
-    def _resolve_any(self, context: TypeContext) -> ResolvedType:
+    def _resolve_any(self, context: TypeContext, required: bool = True) -> ResolvedType:
         """Resolve to Any type."""
         context.add_import("typing", "Any")
-        return ResolvedType(python_type="Any")
+        return ResolvedType(python_type="Any", is_optional=not required)
 
     def _resolve_any_of(
         self, schema: IRSchema, context: TypeContext, required: bool, resolve_underlying: bool = False
     ) -> ResolvedType:
         """Resolve anyOf composition to Union type."""
         if not schema.any_of:
-            return self._resolve_any(context)
+            return self._resolve_any(context, required)
 
         resolved_types = []
         for sub_schema in schema.any_of:
@@ -392,7 +427,7 @@ class OpenAPISchemaResolver(SchemaTypeResolver):
         # For allOf, we typically need to merge the schemas
         # For now, we'll use the first schema if it has a clear type
         if not schema.all_of:
-            return self._resolve_any(context)
+            return self._resolve_any(context, required)
 
         # Simple implementation: use the first concrete schema
         for sub_schema in schema.all_of:
@@ -401,14 +436,14 @@ class OpenAPISchemaResolver(SchemaTypeResolver):
 
         # Fallback - if no schema has a concrete type, return Any
         # Don't recurse into schemas with no type as that causes warnings
-        return self._resolve_any(context)
+        return self._resolve_any(context, required)
 
     def _resolve_one_of(
         self, schema: IRSchema, context: TypeContext, required: bool, resolve_underlying: bool = False
     ) -> ResolvedType:
         """Resolve oneOf composition to Union type."""
         if not schema.one_of:
-            return self._resolve_any(context)
+            return self._resolve_any(context, required)
 
         resolved_types = []
         for sub_schema in schema.one_of:
