@@ -47,13 +47,17 @@ class EndpointResponseHandlerGenerator:
     def __init__(self, schemas: dict[str, Any] | None = None) -> None:
         self.schemas: dict[str, Any] = schemas or {}
 
+    def _register_cattrs_import(self, context: RenderContext) -> None:
+        """Register the cattrs structure_from_dict import."""
+        context.add_import(f"{context.core_package_name}.cattrs_converter", "structure_from_dict")
+
     def _is_type_alias_to_array(self, type_name: str) -> bool:
         """
         Check if a type name corresponds to a type alias that resolves to a List/array type.
 
         This helps distinguish between:
         - Type aliases: AgentHistoryListResponse = List[AgentHistory] (should use array deserialization)
-        - Dataclasses: class AgentHistoryListResponse(BaseSchema): ... (should use .from_dict())
+        - Dataclasses: class AgentHistoryListResponse: ... (should use structure_from_dict())
 
         Args:
             type_name: The Python type name (e.g., "AgentHistoryListResponse")
@@ -92,7 +96,7 @@ class EndpointResponseHandlerGenerator:
 
         This helps distinguish between:
         - Type aliases: StringAlias = str (should use cast())
-        - Dataclasses: class MyModel(BaseSchema): ... (should use .from_dict())
+        - Dataclasses: class MyModel: ... (should use .from_dict())
 
         Args:
             type_name: The Python type name (e.g., "StringAlias")
@@ -125,15 +129,94 @@ class EndpointResponseHandlerGenerator:
 
         return False
 
-    def _should_use_base_schema(self, type_name: str) -> bool:
+    def _extract_array_item_type(self, type_name: str) -> str:
         """
-        Determine if a type should use BaseSchema deserialization.
+        Extract the item type from an array type or type alias.
+
+        Args:
+            type_name: Type name like "List[ItemType]" or "AgentListResponse" (alias to List[Item])
+
+        Returns:
+            The item type as a string (e.g., "ItemType", "AgentListResponseItem")
+        """
+        # If it's already in List[X] format, extract X
+        if type_name.startswith("List[") or type_name.startswith("list["):
+            start_bracket = type_name.find("[")
+            end_bracket = type_name.rfind("]")
+            return type_name[start_bracket + 1 : end_bracket].strip()
+
+        # If it's a type alias, look up the schema and get the items type
+        base_type = type_name
+        if "[" in base_type:
+            base_type = base_type[: base_type.find("[")]
+
+        if base_type in self.schemas:
+            schema = self.schemas[base_type]
+            if getattr(schema, "type", None) == "array" and getattr(schema, "items", None):
+                # Get items schema and resolve its type
+                items_schema = schema.items
+                # Check if items is a reference or inline schema
+                if hasattr(items_schema, "name") and items_schema.name:
+                    return str(items_schema.name)
+                elif hasattr(items_schema, "type"):
+                    # Inline schema - map to Python type
+                    return str(items_schema.type)
+
+        # Fallback: return the original type name (might be primitive List[str])
+        return type_name
+
+    def _is_dataclass_type(self, type_name: str) -> bool:
+        """
+        Check if a type name refers to a dataclass (not a primitive or type alias).
+
+        This is used to determine if a type needs structure_from_dict() deserialisation.
+
+        Args:
+            type_name: The Python type name (e.g., "User", "AgentListResponseItem")
+
+        Returns:
+            True if the type is a dataclass (has properties or type="object")
+        """
+        # Skip obvious primitives and built-ins
+        if type_name in {
+            "str",
+            "int",
+            "float",
+            "bool",
+            "bytes",
+            "None",
+            "Any",
+            "Dict",
+            "List",
+            "dict",
+            "list",
+            "tuple",
+        }:
+            return False
+
+        # Extract base type name without generics
+        base_type = type_name
+        if "[" in base_type:
+            base_type = base_type[: base_type.find("[")]
+
+        # Look up in schemas
+        if base_type in self.schemas:
+            schema = self.schemas[base_type]
+            # Dataclasses have properties or are object type
+            return getattr(schema, "type", None) == "object" or bool(getattr(schema, "properties", None))
+
+        # Heuristic: uppercase names are likely models (not primitives)
+        return base_type[0].isupper() and base_type not in {"Dict", "List", "Union", "Tuple", "Optional"}
+
+    def _should_use_cattrs_structure(self, type_name: str) -> bool:
+        """
+        Determine if a type should use cattrs deserialization.
 
         Args:
             type_name: The Python type name (e.g., "User", "List[User]", "User | None")
 
         Returns:
-            True if the type should use BaseSchema .from_dict() deserialization
+            True if the type should use structure_from_dict() deserialization
         """
         # Extract the base type name from complex types
         base_type = type_name
@@ -173,35 +256,64 @@ class EndpointResponseHandlerGenerator:
         if base_type.startswith(("dict[", "List[", "Union[", "Tuple[", "dict[", "list[", "tuple[")):
             return False
 
-        # Check if this is a type alias (array or non-array) - these should NOT use BaseSchema
-        if self._is_type_alias_to_array(type_name) or self._is_type_alias_to_primitive(type_name):
+        # Check if this is a primitive type alias - these should use cast()
+        if self._is_type_alias_to_primitive(type_name):
             return False
 
-        # All custom model types now inherit from BaseSchema for automatic field mapping
+        # NEW LOGIC: For array type aliases, check if the item type needs deserialisation
+        if self._is_type_alias_to_array(type_name):
+            # Extract item type from List[ItemType] or from the type alias schema
+            item_type = self._extract_array_item_type(type_name)
+            # Check if item type is a dataclass that needs .from_dict()
+            return self._is_dataclass_type(item_type)
+
+        # All custom model types use cattrs via Meta class for automatic field mapping
         # Check if it's a model type (contains a dot indicating it's from models package)
         # or if it's a simple class name that's likely a generated model (starts with uppercase)
         return "." in base_type or (
             base_type[0].isupper() and base_type not in {"Dict", "List", "Union", "Tuple", "dict", "list", "tuple"}
         )
 
-    def _get_base_schema_deserialization_code(self, return_type: str, data_expr: str) -> str:
+    def _register_imports_for_type(self, return_type: str, context: RenderContext) -> None:
         """
-        Generate BaseSchema deserialization code for a given type.
+        Register necessary imports for a return type, including item types for arrays.
 
         Args:
-            return_type: The return type (e.g., "User", "List[User]", "list[User]")
+            return_type: The return type (e.g., "AgentListResponse", "List[User]", "User")
+            context: Render context for import registration
+        """
+        # Register the type itself
+        context.add_typing_imports_for_type(return_type)
+
+        # For array type aliases, also register the item type
+        if self._is_type_alias_to_array(return_type):
+            item_type = self._extract_array_item_type(return_type)
+            context.add_typing_imports_for_type(item_type)
+
+    def _get_cattrs_deserialization_code(self, return_type: str, data_expr: str) -> str:
+        """
+        Generate cattrs deserialization code for a given type.
+
+        Args:
+            return_type: The return type (e.g., "User", "List[User]", "list[User]", "AgentListResponse")
             data_expr: The expression containing the raw data to deserialize
 
         Returns:
-            Code string for deserializing the data using BaseSchema .from_dict()
+            Code string for deserializing the data using structure_from_dict()
         """
+        # Check if this is an array type alias (e.g., AgentListResponse = List[AgentListResponseItem])
+        if self._is_type_alias_to_array(return_type):
+            # Extract the item type from the type alias
+            item_type = self._extract_array_item_type(return_type)
+            return f"[structure_from_dict(item, {item_type}) for item in {data_expr}]"
+
         if return_type.startswith("List[") or return_type.startswith("list["):
             # Handle List[Model] or list[Model] types
             if return_type.startswith("List["):
                 item_type = return_type[5:-1]  # Remove 'List[' and ']'
             else:  # starts with "list["
                 item_type = return_type[5:-1]  # Remove 'list[' and ']'
-            return f"[{item_type}.from_dict(item) for item in {data_expr}]"
+            return f"[structure_from_dict(item, {item_type}) for item in {data_expr}]"
         elif return_type.startswith("Optional["):
             # SANITY CHECK: Unified type system should never produce Optional[X]
             logger.error(
@@ -214,10 +326,10 @@ class EndpointResponseHandlerGenerator:
 
             # Check if inner type is also a list
             if inner_type.startswith("List[") or inner_type.startswith("list["):
-                list_code = self._get_base_schema_deserialization_code(inner_type, data_expr)
+                list_code = self._get_cattrs_deserialization_code(inner_type, data_expr)
                 return f"{list_code} if {data_expr} is not None else None"
             else:
-                return f"{inner_type}.from_dict({data_expr}) if {data_expr} is not None else None"
+                return f"structure_from_dict({data_expr}, {inner_type}) if {data_expr} is not None else None"
         elif " | None" in return_type or return_type.endswith("| None"):
             # Handle Model | None types (modern Python 3.10+ syntax)
             # Extract base type from "X | None" pattern
@@ -228,15 +340,15 @@ class EndpointResponseHandlerGenerator:
 
             # Check if inner type is also a list
             if inner_type.startswith("List[") or inner_type.startswith("list["):
-                list_code = self._get_base_schema_deserialization_code(inner_type, data_expr)
+                list_code = self._get_cattrs_deserialization_code(inner_type, data_expr)
                 return f"{list_code} if {data_expr} is not None else None"
             else:
-                return f"{inner_type}.from_dict({data_expr}) if {data_expr} is not None else None"
+                return f"structure_from_dict({data_expr}, {inner_type}) if {data_expr} is not None else None"
         else:
             # Handle simple Model types only - this should not be called for list types
             if "[" in return_type and "]" in return_type:
                 # This is a complex type that we missed - should not happen
-                raise ValueError(f"Unsupported complex type for BaseSchema deserialization: {return_type}")
+                raise ValueError(f"Unsupported complex type for cattrs deserialization: {return_type}")
 
             # Safety check: catch the specific issue we're debugging
             if return_type.startswith("list[") or return_type.startswith("List["):
@@ -244,7 +356,7 @@ class EndpointResponseHandlerGenerator:
                     f"CRITICAL BUG: List type {return_type} reached simple type handler! This should never happen."
                 )
 
-            return f"{return_type}.from_dict({data_expr})"
+            return f"structure_from_dict({data_expr}, {return_type})"
 
     def _get_extraction_code(
         self,
@@ -297,16 +409,16 @@ class EndpointResponseHandlerGenerator:
         else:  # Includes schema-defined models, List[], dict[], Optional[]
             context.add_typing_imports_for_type(return_type)  # Ensure model itself is imported
 
-            # Check if we should use BaseSchema deserialization instead of cast()
-            use_base_schema = self._should_use_base_schema(return_type)
+            # Check if we should use cattrs deserialization instead of cast()
+            use_base_schema = self._should_use_cattrs_structure(return_type)
 
             if not use_base_schema:
-                # Fallback to cast() for non-BaseSchema types
+                # Fallback to cast() for non-dataclass types
                 context.add_import("typing", "cast")
 
             # Direct deserialization using schemas as-is (no unwrapping)
             if use_base_schema:
-                deserialization_code = self._get_base_schema_deserialization_code(return_type, "response.json()")
+                deserialization_code = self._get_cattrs_deserialization_code(return_type, "response.json()")
                 return deserialization_code
             else:
                 return f"cast({return_type}, response.json())"
@@ -361,17 +473,18 @@ class EndpointResponseHandlerGenerator:
                         # Resolve the specific return type for this response
                         resp_schema = self._get_response_schema(resp_ir)
                         if resp_schema:
+                            # Use response.json() directly - no automatic unwrapping
+                            data_expr = "response.json()"
+
                             type_service = UnifiedTypeService(self.schemas)
                             response_type = type_service.resolve_schema_type(resp_schema, context)
-                            if self._should_use_base_schema(response_type):
-                                deserialization_code = self._get_base_schema_deserialization_code(
-                                    response_type, "response.json()"
-                                )
+                            if self._should_use_cattrs_structure(response_type):
+                                deserialization_code = self._get_cattrs_deserialization_code(response_type, data_expr)
                                 writer.write_line(f"return {deserialization_code}")
-                                context.add_typing_imports_for_type(response_type)
+                                self._register_imports_for_type(response_type, context)
                             else:
                                 context.add_import("typing", "cast")
-                                writer.write_line(f"return cast({response_type}, response.json())")
+                                writer.write_line(f"return cast({response_type}, {data_expr})")
                         else:
                             writer.write_line("return None")
                 else:
@@ -444,16 +557,27 @@ class EndpointResponseHandlerGenerator:
                 writer.write_line("return  # Explicit return for async generator")
             return
 
-        # Handle responses using the schema as-is from the OpenAPI spec (no unwrapping)
+        # Use response.json() directly - no automatic unwrapping
+        data_expr = "response.json()"
+
+        # Handle responses using the schema
         if strategy.return_type.startswith("Union["):
-            # Special handling for Union types with try/except fallback
-            self._write_union_response_handling(writer, context, strategy.return_type, "response.json()")
-        elif self._should_use_base_schema(strategy.return_type):
-            deserialization_code = self._get_base_schema_deserialization_code(strategy.return_type, "response.json()")
+            # Check if this is a multi-content-type Union (has content_type_mapping)
+            if strategy.content_type_mapping:
+                # Generate Content-Type header checking code
+                self._write_content_type_conditional_handling(writer, context, strategy)
+            else:
+                # Traditional Union handling with try/except fallback
+                self._write_union_response_handling(writer, context, strategy.return_type, data_expr)
+        elif self._should_use_cattrs_structure(strategy.return_type):
+            # Register cattrs import
+            context.add_import(f"{context.core_package_name}.cattrs_converter", "structure_from_dict")
+            deserialization_code = self._get_cattrs_deserialization_code(strategy.return_type, data_expr)
             writer.write_line(f"return {deserialization_code}")
+            self._register_imports_for_type(strategy.return_type, context)
         else:
             context.add_import("typing", "cast")
-            writer.write_line(f"return cast({strategy.return_type}, response.json())")
+            writer.write_line(f"return cast({strategy.return_type}, {data_expr})")
 
     def _get_response_schema(self, response_ir: IRResponse) -> IRSchema | None:
         """Extract the schema from a response IR."""
@@ -495,9 +619,9 @@ class EndpointResponseHandlerGenerator:
         # Try the first type
         writer.write_line("try:")
         writer.indent()
-        if self._should_use_base_schema(first_type):
+        if self._should_use_cattrs_structure(first_type):
             context.add_typing_imports_for_type(first_type)
-            deserialization_code = self._get_base_schema_deserialization_code(first_type, data_expr)
+            deserialization_code = self._get_cattrs_deserialization_code(first_type, data_expr)
             writer.write_line(f"return {deserialization_code}")
         else:
             context.add_import("typing", "cast")
@@ -512,9 +636,9 @@ class EndpointResponseHandlerGenerator:
             else:
                 writer.write_line("except Exception:  # Attempt to parse as the next type")
             writer.indent()
-            if self._should_use_base_schema(type_name):
+            if self._should_use_cattrs_structure(type_name):
                 context.add_typing_imports_for_type(type_name)
-                deserialization_code = self._get_base_schema_deserialization_code(type_name, data_expr)
+                deserialization_code = self._get_cattrs_deserialization_code(type_name, data_expr)
                 if is_last:
                     writer.write_line(f"return {deserialization_code}")
                 else:
@@ -526,3 +650,61 @@ class EndpointResponseHandlerGenerator:
                 context.add_import("typing", "cast")
                 writer.write_line(f"return cast({type_name}, {data_expr})")
             writer.dedent()
+
+    def _write_content_type_conditional_handling(
+        self, writer: CodeWriter, context: RenderContext, strategy: ResponseStrategy
+    ) -> None:
+        """Write Content-Type header checking code for multi-content-type responses.
+
+        When a response has multiple content types, generate conditional code that checks
+        the Content-Type header and returns the appropriate type.
+
+        Args:
+            writer: Code writer for output
+            context: Render context for imports
+            strategy: Response strategy with content_type_mapping
+        """
+        if not strategy.content_type_mapping:
+            raise ValueError("content_type_mapping is required for Content-Type conditional handling")
+
+        # Extract content type without parameters and normalize to lowercase for case-insensitive comparison
+        # (e.g., "Application/JSON; charset=utf-8" -> "application/json")
+        # RFC 7230: HTTP header field names are case-insensitive
+        writer.write_line('content_type = response.headers.get("content-type", "").split(";")[0].strip().lower()')
+        writer.write_line("")
+
+        # Generate if/elif/else chain for each content type
+        content_type_items = list(strategy.content_type_mapping.items())
+
+        for i, (content_type, python_type) in enumerate(content_type_items):
+            is_first = i == 0
+            is_last = i == len(content_type_items) - 1
+
+            # Write conditional statement with lowercase content-type (case-insensitive comparison)
+            content_type_lower = content_type.lower()
+            if is_first:
+                writer.write_line(f'if content_type == "{content_type_lower}":')
+            elif not is_last:
+                writer.write_line(f'elif content_type == "{content_type_lower}":')
+            else:
+                # Last item - use else for fallback
+                writer.write_line("else:  # Default/fallback content type")
+
+            writer.indent()
+
+            # Generate return statement based on python_type
+            if python_type == "bytes":
+                writer.write_line("return response.content")
+            elif python_type == "str":
+                writer.write_line("return response.text")
+            elif self._should_use_cattrs_structure(python_type):
+                # Complex type - use cattrs deserialization
+                context.add_typing_imports_for_type(python_type)
+                deserialization_code = self._get_cattrs_deserialization_code(python_type, "response.json()")
+                writer.write_line(f"return {deserialization_code}")
+            else:
+                # Simple type - use cast
+                context.add_import("typing", "cast")
+                writer.write_line(f"return cast({python_type}, response.json())")
+
+            writer.dedent()
