@@ -16,12 +16,12 @@ class TestParseOneOfSchemas(unittest.TestCase):
         """Set up for test cases."""
         self.context = ParsingContext(raw_spec_schemas={}, parsed_schemas={}, visited_refs=set())
         self.mock_parse_fn = MagicMock(
-            spec=Callable[[Optional[str], Optional[Mapping[str, Any]], ParsingContext, int], IRSchema]
+            spec=Callable[[str | None, Optional[Mapping[str, Any]], ParsingContext, int], IRSchema]
         )
 
         # Default side effect for the mock_parse_fn
         def default_parse_fn_side_effect(
-            name: Optional[str],
+            name: str | None,
             node: Optional[Mapping[str, Any]],
             context: ParsingContext,
             max_depth: int,
@@ -109,7 +109,7 @@ class TestParseOneOfSchemas(unittest.TestCase):
         boolean_schema = IRSchema(name="GenBool", type="boolean")
 
         def side_effect(
-            name: Optional[str], node_data: Optional[Mapping[str, Any]], context: ParsingContext, max_depth: int
+            name: str | None, node_data: Optional[Mapping[str, Any]], context: ParsingContext, max_depth: int
         ) -> IRSchema:
             if node_data == one_of_nodes[0]:
                 return string_schema
@@ -160,7 +160,7 @@ class TestParseOneOfSchemas(unittest.TestCase):
         my_ref_schema = IRSchema(name="MyRef", type="object")
 
         def side_effect(
-            name: Optional[str], node_data: Optional[Mapping[str, Any]], context: ParsingContext, max_depth: int
+            name: str | None, node_data: Optional[Mapping[str, Any]], context: ParsingContext, max_depth: int
         ) -> IRSchema:
             if node_data == simple_type_node:
                 return number_schema
