@@ -102,13 +102,19 @@ def test_endpoints_emitter__multiple_operations_with_tags__generates_separate_ta
 
     # Check content of pets file
     pets_content = pets_file.read_text()
-    assert "class PetsClient:" in pets_content
+    # Check for Protocol
+    assert "class PetsClientProtocol(Protocol):" in pets_content
+    # Check for implementation with Protocol inheritance
+    assert "class PetsClient(PetsClientProtocol):" in pets_content
     assert "async def list_pets" in pets_content
     assert "async def create_pet" in pets_content
 
     # Check content of users file
     users_content = users_file.read_text()
-    assert "class UsersClient:" in users_content
+    # Check for Protocol
+    assert "class UsersClientProtocol(Protocol):" in users_content
+    # Check for implementation with Protocol inheritance
+    assert "class UsersClient(UsersClientProtocol):" in users_content
     assert "async def list_users" in users_content
 
 
@@ -804,9 +810,9 @@ def test_endpoints_emitter__query_params_included_in_params_dict(
     # Read the generated code
     with open(os.path.join(out_dir, "endpoints", "tenants.py")) as f:
         content = f.read()
-    # Assert that all query params are included in the params dict
-    assert '"start_date": start_date' in content
-    assert '"end_date": end_date' in content
+    # Assert that all query params are included in the params dict with serialization
+    assert '"start_date": DataclassSerializer.serialize(start_date)' in content
+    assert '"end_date": DataclassSerializer.serialize(end_date)' in content
     # Also check that tenant_id is not in params (it's a path param)
     assert '"tenant_id": tenant_id' not in content
 
