@@ -145,7 +145,7 @@ def test_models_emitter__object_with_array_property__generates_list_type_annotat
     assert "from dataclasses import dataclass" in result
     assert "from typing import" in result
     assert "@dataclass" in result
-    assert "class PetList(BaseSchema):" in result
+    assert "class PetList:" in result
     # Check for the item model import and type (now using correct same-directory relative imports)
     assert "from .pet_list_items_item import PetListItemsItem" in result
     # Check for the field - it should have the union syntax for optional
@@ -197,7 +197,7 @@ def test_models_emitter_datetime(tmp_path: Path) -> None:
     # Python 3.10+ doesn't need typing.Optional for | None syntax, only datetime imports
     assert "from datetime import" in result
     assert "@dataclass" in result
-    assert "class Event(BaseSchema):" in result
+    assert "class Event:" in result
     assert "created_at: datetime | None" in result
     assert "date_only: date | None" in result
 
@@ -382,7 +382,7 @@ def test_models_emitter__array_of_models_alias(tmp_path: Path) -> None:
     assert item_model_file.exists()
     item_content = item_model_file.read_text()
     assert "@dataclass" in item_content
-    assert "class Item(BaseSchema):" in item_content
+    assert "class Item:" in item_content
 
     # Check ItemList.py (should be a type alias to List[Item])
     list_model_file: Path = out_dir / "models" / "item_list.py"  # module name sanitized
@@ -595,7 +595,7 @@ def test_models_emitter_optional_list_factory(tmp_path: Path) -> None:
     assert "from dataclasses import dataclass, field" in content
     assert "from typing import List" in content  # Python 3.10+ doesn't need Optional import for | None syntax
     assert "@dataclass" in content
-    assert "class Config_(BaseSchema):" in content  # 'Config' is sanitized to 'Config_' because 'config' is reserved
+    assert "class Config_:" in content  # 'Config' is sanitized to 'Config_' because 'config' is reserved
     # Field should be List[str] | None and use field(default_factory=list)
     assert "tags: List[str] | None = field(default_factory=list)" in content
 
@@ -624,7 +624,7 @@ def test_models_emitter_optional_named_object_none_default(tmp_path: Path) -> No
     address_file: Path = out_dir / "models" / "address.py"
     assert address_file.exists()
     address_content = address_file.read_text()
-    assert "class Address(BaseSchema):" in address_content
+    assert "class Address:" in address_content
 
     # Check User.py
     user_file: Path = out_dir / "models" / "user.py"
