@@ -62,12 +62,12 @@ class TestAgentIncludeParameterTyping(unittest.TestCase):
         # Note: The exact enum name may vary based on the generation strategy
         import re
 
-        # Pattern to match include parameter with any enum type
-        include_pattern = r"include: Optional\[List\[([A-Za-z0-9_]+)\]\]"
+        # Pattern to match include parameter with any enum type (using union syntax)
+        include_pattern = r"include: List\[([A-Za-z0-9_]+)\] \| None"
         match = re.search(include_pattern, agents_code)
 
         self.assertIsNotNone(
-            match, "include parameter should be typed as Optional[List[SomeEnumType]] but pattern not found"
+            match, "include parameter should be typed as List[SomeEnumType] | None but pattern not found"
         )
 
         enum_type_name = match.group(1)
@@ -129,9 +129,16 @@ class TestAgentIncludeParameterTyping(unittest.TestCase):
             with open(anonymous_array_item_path, "r") as f:
                 content = f.read()
 
-            # AnonymousArrayItem should be related to chat messages, not include parameters
-            self.assertIn("message", content.lower(), "AnonymousArrayItem appears to be a message-related type")
-            self.assertIn("role", content.lower(), "AnonymousArrayItem appears to be a message-related type with role")
+            # AnonymousArrayItem may be a circular reference placeholder or message-related type
+            # Check if it's a circular reference (detected properly by unified cycle detection)
+            is_circular_placeholder = "circular reference detected" in content.lower()
+
+            if not is_circular_placeholder:
+                # If not a circular reference, it should be related to chat messages
+                self.assertIn("message", content.lower(), "AnonymousArrayItem appears to be a message-related type")
+                self.assertIn(
+                    "role", content.lower(), "AnonymousArrayItem appears to be a message-related type with role"
+                )
 
             # It should NOT be used for include parameters
             # This test documents the current incorrect behavior
